# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import user_dashboard_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2


class UserDashboardStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.UserDashboard/create',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.CreateUserDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.UserDashboard/update',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UpdateUserDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.UserDashboard/delete',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.UserDashboard/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.GetUserDashboardRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.UserDashboard/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.UserDashboard/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class UserDashboardServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new UserDashboard. Users can use the dashboard in `private`. In addition to the widgets provided by Cloudforet by default, Users can use widgets through the CustomWidget resource to create a UserDashboard that suits their needs.
        request_example: >-
        {
        "name": "Untitled Dashboard",
        "custom_layouts": [
        [
        {
        "name": "AWS Data-Transfer Cost Trend",
        "widget_id": "linegraph-lg-02",
        "options": {
        "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_COST_TREND_DESC",
        "chart_type": "LINE",
        "chart_img": "AWS_Data-Transfer_Cost_Trend"
        }
        }
        ],
        [
        {
        "options": {
        "chart_type": "MAP",
        "chart_img": "AWS_Data-Transfer_By_Region",
        "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_BY_REGION_DESC"
        },
        "name": "AWS Data-Transfer by Region",
        "widget_id": "map-lg-02"
        }
        ],
        [
        {
        "options": {
        "group_by": "project_id",
        "layout": 100.0,
        "chart_type": "STACKED_COLUMN",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_CLOUDFRONT_COST_DESC",
        "chart_img": "AWS_CloudFront_Cost"
        },
        "name": "AWS CloudFront Cost by Project",
        "widget_id": "stackedcol-lg-03"
        }
        ]
        ],
        "default_filter": {},
        "period_type": "AUTO"
        }
        response_example: >-
        {
        "user_dashboard_id": "user-dash-bf3f5f5ffa03",
        "name": "Untitled Dashboard",
        "custom_layouts": [
        [
        {
        "options": {
        "chart_type": "LINE",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_COST_TREND_DESC",
        "layout": 100.0,
        "chart_img": "AWS_Data-Transfer_Cost_Trend"
        },
        "widget_id": "linegraph-lg-02",
        "name": "AWS Data-Transfer Cost Trend"
        }
        ],
        [
        {
        "name": "AWS Data-Transfer by Region",
        "widget_id": "map-lg-02",
        "options": {
        "chart_img": "AWS_Data-Transfer_By_Region",
        "chart_type": "MAP",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_BY_REGION_DESC",
        "layout": 100.0
        }
        }
        ],
        [
        {
        "widget_id": "stackedcol-lg-03",
        "name": "AWS CloudFront Cost by Project",
        "options": {
        "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_CLOUDFRONT_COST_DESC",
        "chart_img": "AWS_CloudFront_Cost",
        "group_by": "project_id",
        "chart_type": "STACKED_COLUMN"
        }
        }
        ]
        ],
        "default_filter": {},
        "period_type": "AUTO",
        "tags": {},
        "user_id": "seolmin@mz.co.kr",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T05:58:52.065Z",
        "updated_at": "2022-07-19T05:58:52.065Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific UserDashboard. You can make changes in widgets, including default widgets and CustomWidegets.
        request_example: >-
        {
        "user_dashboard_id": "user-dash-bf3f5f5ffa03",
        "name": "Untitled Dashboard2",
        "custom_layouts": [
        [{
        "options": {
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_COST_TREND_DESC",
        "chart_type": "LINE", "chart_img": "AWS_Data-Transfer_Cost_Trend", "layout": 100.0},
        "name": "AWS Data-Transfer Cost Trend",
        "widget_id": "linegraph-lg-02"}],
        [{
        "name": "AWS Data-Transfer by Region",
        "options": {
        "chart_type": "MAP",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_BY_REGION_DESC",
        "layout": 100.0,
        "chart_img": "AWS_Data-Transfer_By_Region"},
        "widget_id": "map-lg-02"}],
        [{
        "name": "AWS CloudFront Cost by Project",
        "widget_id": "stackedcol-lg-03",
        "options": {
        "layout": 100.0,
        "chart_img": "AWS_CloudFront_Cost",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_CLOUDFRONT_COST_DESC",
        "chart_type": "STACKED_COLUMN",
        "group_by": "project_id"}
        }]
        ]
        }
        response_example: >-
        {
        "user_dashboard_id": "user-dash-bf3f5f5ffa03",
        "name": "Untitled Dashboard2",
        "custom_layouts": [
        [
        {
        "options": {
        "chart_type": "LINE",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_COST_TREND_DESC",
        "layout": 100.0,
        "chart_img": "AWS_Data-Transfer_Cost_Trend"
        },
        "widget_id": "linegraph-lg-02",
        "name": "AWS Data-Transfer Cost Trend"
        }
        ],
        [
        {
        "name": "AWS Data-Transfer by Region",
        "widget_id": "map-lg-02",
        "options": {
        "chart_img": "AWS_Data-Transfer_By_Region",
        "chart_type": "MAP",
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_DATA_TRANSFER_BY_REGION_DESC",
        "layout": 100.0
        }
        }
        ],
        [
        {
        "widget_id": "stackedcol-lg-03",
        "name": "AWS CloudFront Cost by Project",
        "options": {
        "layout": 100.0,
        "chart_desc_translation_id": "BILLING.COST_MANAGEMENT.DASHBOARD.CUSTOMIZE.ADD_WIDGET_MODAL.AWS_CLOUDFRONT_COST_DESC",
        "chart_img": "AWS_CloudFront_Cost",
        "group_by": "project_id",
        "chart_type": "STACKED_COLUMN"
        }
        }
        ]
        ],
        "default_filter": {},
        "period_type": "AUTO",
        "tags": {},
        "user_id": "seolmin@mz.co.kr",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T05:58:52.065Z",
        "updated_at": "2022-07-19T05:58:52.065Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific UserDashboard. You must specify the `user_dashboard_id` of the UserDashboard to delete.
        request_example: >-
        {
        "user_dashboard_id": "user-dash-d1bd5d8cb6d7"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific UserDashboard. Prints detailed information about the UserDashboard, including widegts used.
        request_example: >-
        {
        "user_dashboard_id": "user-dash-d1bd5d8cb6d7"
        }
        response_example: >-
        {
        "user_dashboard_id": "user-dash-d1bd5d8cb6d7",
        "name": "11 Months Public Cloud Cost Summary",
        "custom_layouts": [
        [
        {
        "widget_id": "card-lg-01",
        "options": {
        "chart_type": "CARD",
        "layout": 100.0
        },
        "name": "Budget Usage Summary"
        }
        ],
        [
        {
        "options": {
        "layout": 100.0,
        "chart_type": "TABLE"
        },
        "name": "Project-wise Budget Usage Summary@@",
        "widget_id": "table-lg-01"
        }
        ],
        [
        {
        "name": "Cost Trend By Product",
        "options": {
        "chart_type": "STACKED_COLUMN",
        "layout": 100.0,
        "group_by": "product"
        },
        "widget_id": "stackedcol-lg-02"
        }
        ]
        ],
        "default_filter": {
        "project_id": []
        },
        "period_type": "FIXED",
        "period": {
        "start": "2021-04-01",
        "end": "2022-02-28"
        },
        "tags": {},
        "user_id": "wanzargen@mz.co.kr",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-03-03T03:36:35.396Z",
        "updated_at": "2022-03-03T03:36:35.396Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all UserDashboards. You can use a query to get a filtered list of UserDashboards.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "user_dashboard_id": "user-dash-d1bd5d8cb6d7",
        "name": "11 Months Public Cloud Cost Summary",
        "custom_layouts": [
        [
        {
        "options": {
        "layout": 100.0,
        "chart_type": "CARD"
        },
        "widget_id": "card-lg-01",
        "name": "Budget Usage Summary"
        }
        ],
        [
        {
        "name": "Project-wise Budget Usage Summary@@",
        "options": {
        "chart_type": "TABLE",
        "layout": 100.0
        },
        "widget_id": "table-lg-01"
        }
        ],
        [
        {
        "widget_id": "stackedcol-lg-02",
        "options": {
        "layout": 100.0,
        "group_by": "product",
        "chart_type": "STACKED_COLUMN"
        },
        "name": "Cost Trend By Product"
        }
        ]
        ],
        "default_filter": {
        "project_id": []
        },
        "period_type": "FIXED",
        "period": {
        "start": "2021-04-01",
        "end": "2022-02-28"
        },
        "tags": {},
        "user_id": "wanzargen@mz.co.kr",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-03-03T03:36:35.396Z",
        "updated_at": "2022-03-03T03:36:35.396Z"
        },
        {
        "user_dashboard_id": "user-dash-965b03793d5b",
        "name": "AWS CloudFront Cost by Project",
        "custom_layouts": [
        [
        {
        "name": "AWS CloudFront Cost by Project",
        "widget_id": "stackedcol-lg-03",
        "options": {
        "chart_type": "STACKED_COLUMN",
        "layout": 100.0
        }
        }
        ],
        [
        {
        "widget_id": "stackedcol-lg-03",
        "options": {
        "layout": 100.0,
        "chart_type": "STACKED_COLUMN",
        "group_by": "service_account_id"
        },
        "name": "AWS CloudFront Cost by Service Account"
        }
        ],
        [
        {
        "options": {
        "layout": 100.0,
        "chart_type": "LINE"
        },
        "name": "AWS Data-Transfer Cost Trend",
        "widget_id": "linegraph-lg-02"
        }
        ]
        ],
        "default_filter": {},
        "period_type": "FIXED",
        "period": {
        "start": "2021-05-01",
        "end": "2022-04-30"
        },
        "tags": {},
        "user_id": "wanzargen@mz.co.kr",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-04-07T01:13:28.494Z",
        "updated_at": "2022-04-07T01:13:28.494Z"
        }
        ],
        "total_count": 48
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_UserDashboardServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.CreateUserDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UpdateUserDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.GetUserDashboardRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.UserDashboard', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class UserDashboard(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.UserDashboard/create',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.CreateUserDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.UserDashboard/update',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UpdateUserDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.UserDashboard/delete',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.UserDashboard/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.GetUserDashboardRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.UserDashboard/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.UserDashboard/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_user__dashboard__pb2.UserDashboardStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.statistics.v1 import resource_pb2 as spaceone_dot_api_dot_statistics_dot_v1_dot_resource__pb2


class ResourceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.stat = channel.unary_unary(
                '/spaceone.api.statistics.v1.Resource/stat',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_resource__pb2.ResourceStatRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class ResourceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def stat(self, request, context):
        """
        desc: Enables data preprocessing of different services. Although limited, it is possible to create not only basic queries but also data suitable for users' needs, such as joins between two tables created by the query, handling missing values, and sorting.
        request_example: >-
        {
        "aggregate": [
        {"query": {"resource_type": "inventory.CloudServiceType",
        "query": {
        "filter": [{"k": "labels", "v": ["Server"], "o": "in"},
        {"k": "is_primary", "v": true, "o": "eq"}], "aggregate": [{
        "group": {
        "keys": [
        {
        "key": "cloud_service_type_id",
        "name": "cloud_service_type_id"},
        {
        "key": "name",
        "name": "cloud_service_type"},
        {
        "key": "group",
        "name": "cloud_service_group"},
        {
        "key": "provider",
        "name": "provider"},
        {
        "key": "cloud_service_type_id",
        "name": "cloud_service_type_id"}],
        "fields": [
        {
        "key": "tags",
        "name": "tags",
        "operator": "first"},
        {
        "key": "labels",
        "name": "labels",
        "operator": "first"}]}}]}}},
        {"join": {"resource_type": "inventory.CloudService", "query": {"filter": [
        {"k": "ref_cloud_service_type.cloud_service_type_id",
        "v": ["cloud-svc-type-58c926b19aca", "cloud-svc-type-c7e5bc38d911",
        "cloud-svc-type-8dd4d7a13b95", "cloud-svc-type-719e705cb529",
        "cloud-svc-type-50bd62cf6e0e"], "o": "in"}], "aggregate": [{"group": {
        "keys": [{"key": "cloud_service_type", "name": "cloud_service_type"},
        {"key": "cloud_service_group", "name": "cloud_service_group"},
        {"key": "provider", "name": "provider"}],
        "fields": [{"name": "count", "operator": "count"}]}}]},
        "keys": ["cloud_service_type", "cloud_service_group", "provider"]}},
        {"fill_na": {"data": {"count": 0.0}}}, {"formula": {"query": "count > 0"}},
        {"sort": {"key": "count", "desc": true}}],
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "total_count": 5.0,
        "results": [
        {
        "labels": [
        "Compute",
        "Server"
        ],
        "cloud_service_type_id": "cloud-svc-type-58c926b19aca",
        "cloud_service_type": "Instance",
        "count": 44.0,
        "tags": [
        {
        "key": "spaceone:icon",
        "value": "https://spaceone-custom-assets.s3.ap-northeast-2.amazonaws.com/console-assets/icons/aws-ec2.svg"
        }
        ],
        "provider": "aws",
        "cloud_service_group": "EC2"
        },
        {
        "tags": [
        {
        "key": "spaceone:icon",
        "value": "https://spaceone-custom-assets.s3.ap-northeast-2.amazonaws.com/console-assets/icons/cloud-services/openstack/openstack_compute.svg"
        },
        {
        "key": "spaceone:display_name",
        "value": "Instance"
        }
        ],
        "cloud_service_group": "Compute",
        "cloud_service_type": "Instance",
        "provider": "openstack",
        "count": 12.0,
        "labels": [
        "Compute",
        "Server"
        ],
        "cloud_service_type_id": "cloud-svc-type-50bd62cf6e0e"
        },
        {
        "cloud_service_type": "Node",
        "count": 8.0,
        "provider": "kubernetes",
        "cloud_service_type_id": "cloud-svc-type-719e705cb529",
        "cloud_service_group": "Cluster",
        "tags": [
        {
        "value": "https://spaceone-custom-assets.s3.ap-northeast-2.amazonaws.com/console-assets/icons/cloud-services/kubernetes/node.svg",
        "key": "spaceone:icon"
        }
        ],
        "labels": [
        "Compute",
        "Server",
        "Container"
        ]
        },
        {
        "cloud_service_type_id": "cloud-svc-type-8dd4d7a13b95",
        "cloud_service_type": "Instance",
        "cloud_service_group": "ComputeEngine",
        "labels": [
        "Compute",
        "Server"
        ],
        "tags": [
        {
        "key": "spaceone:icon",
        "value": "https://spaceone-custom-assets.s3.ap-northeast-2.amazonaws.com/console-assets/icons/cloud-services/google_cloud/Compute_Engine.svg"
        }
        ],
        "count": 5.0,
        "provider": "google_cloud"
        },
        {
        "tags": [
        {
        "value": "https://spaceone-custom-assets.s3.ap-northeast-2.amazonaws.com/console-assets/icons/azure-vm.svg",
        "key": "spaceone:icon"
        }
        ],
        "cloud_service_type": "VirtualMachine",
        "cloud_service_group": "Compute",
        "count": 2.0,
        "provider": "azure",
        "cloud_service_type_id": "cloud-svc-type-c7e5bc38d911",
        "labels": [
        "Compute",
        "Server"
        ]
        }
        ]
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ResourceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_resource__pb2.ResourceStatRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.statistics.v1.Resource', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Resource(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Resource/stat',
            spaceone_dot_api_dot_statistics_dot_v1_dot_resource__pb2.ResourceStatRequest.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.notification.v1 import protocol_pb2 as spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2


class ProtocolStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/create',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.CreateProtocolRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/update',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.UpdateProtocolRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
                )
        self.update_plugin = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/update_plugin',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.UpdateProtocolPluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/enable',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/disable',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/delete',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/get',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.GetProtocolRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/list',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.notification.v1.Protocol/stat',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class ProtocolServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Protocol. When creating a protocol, you must specify the plugins provided from the repository, and you must also set the credentials to be set in the plugin if necessary.
        request_example: >-
        {
        "name": "Email",
        "plugin_info": {
        "plugin_id": "plugin-email-noti-protocol",
        "version": "1.0.1",
        "options": {},
        "secret_id": "secret-123546789012",
        "metadata": {
        "data": {
        "schema": {
        "properties": {
        "email": {
        "pattern": "^[\\W]*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4}[\\W]*,{1}[\\W]*)*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4})[\\W]*$",
        "examples": [
        "user1@test.com, user2@test.com"
        ],
        "minLength": 10.0,
        "description": "Email address to receive notifications",
        "type": "string",
        "title": "Email Address"
        }
        },
        "required": [
        "email"
        ],
        "type": "object"
        }
        },
        "data_type": "PLAIN_TEXT"
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {}
        }
        response_example: >-
        {
        "protocol_id": "protocol-123546789012",
        "name": "Email",
        "state": "ENABLED",
        "protocol_type": "EXTERNAL",
        "capability": {
        "supported_schema": [
        "email_smtp"
        ]
        },
        "plugin_info": {
        "plugin_id": "plugin-email-noti-protocol",
        "version": "1.0.1",
        "options": {},
        "secret_id": "secret-123546789012",
        "metadata": {
        "data": {
        "schema": {
        "properties": {
        "email": {
        "pattern": "^[\\W]*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4}[\\W]*,{1}[\\W]*)*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4})[\\W]*$",
        "examples": [
        "user1@test.com, user2@test.com"
        ],
        "minLength": 10.0,
        "description": "Email address to receive notifications",
        "type": "string",
        "title": "Email Address"
        }
        },
        "required": [
        "email"
        ],
        "type": "object"
        }
        },
        "data_type": "PLAIN_TEXT"
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {},
        "domain_id": "domain-123546789012",
        "created_at": "2022-01-01T07:55:57.043Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Protocol. The method `update` can update the name and tags only. If you want to update the plugin version or options, you can use `update_plugin` method.
        request_example: >-
        {
        "protocol_id": "protocol-123456789012",
        "name": "Email-test",
        "tags": {
        "type": "test"
        }
        }
        response_example: >-
        {
        "protocol_id": "protocol-123546789012",
        "name": "Email-test",
        "state": "ENABLED",
        "protocol_type": "EXTERNAL",
        "capability": {
        "supported_schema": [
        "email_smtp"
        ]
        },
        "plugin_info": {
        "plugin_id": "plugin-email-noti-protocol",
        "version": "1.0.1",
        "options": {},
        "secret_id": "secret-123546789012",
        "metadata": {
        "data": {
        "schema": {
        "properties": {
        "email": {
        "pattern": "^[\\W]*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4}[\\W]*,{1}[\\W]*)*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4})[\\W]*$",
        "examples": [
        "user1@test.com, user2@test.com"
        ],
        "minLength": 10.0,
        "description": "Email address to receive notifications",
        "type": "string",
        "title": "Email Address"
        }
        },
        "required": [
        "email"
        ],
        "type": "object"
        }
        },
        "data_type": "PLAIN_TEXT"
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "type": "test"
        },
        "domain_id": "domain-123546789012",
        "created_at": "2022-01-01T07:55:57.043Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_plugin(self, request, context):
        """
        desc: Updates a plugin for a Protocol. It is usually used when redeploying a plugin to a new version.
        request_example: >-
        {
        "protocol_id": "protocol-123456789012",
        "version": "1.0.2",
        "options": {}
        }
        response_example: >-
        {
        "protocol_id": "protocol-123546789012",
        "name": "Email-test",
        "state": "ENABLED",
        "protocol_type": "EXTERNAL",
        "capability": {
        "supported_schema": [
        "email_smtp"
        ]
        },
        "plugin_info": {
        "plugin_id": "plugin-email-noti-protocol",
        "version": "1.0.2",
        "options": {},
        "secret_id": "secret-123546789012",
        "metadata": {
        "data": {
        "schema": {
        "properties": {
        "email": {
        "pattern": "^[\\W]*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4}[\\W]*,{1}[\\W]*)*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4})[\\W]*$",
        "examples": [
        "user1@test.com, user2@test.com"
        ],
        "minLength": 10.0,
        "description": "Email address to receive notifications",
        "type": "string",
        "title": "Email Address"
        }
        },
        "required": [
        "email"
        ],
        "type": "object"
        }
        },
        "data_type": "PLAIN_TEXT"
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "type": "test"
        },
        "domain_id": "domain-123546789012",
        "created_at": "2022-01-01T07:55:57.043Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific Protocol. If the Protocol is enabled, the Protocol can be used and the Notification can be dispatched.
        request_example: >-
        {
        "protocol_id": "protocol-123456789012"
        }
        response_example: >-
        {
        "protocol_id": "protocol-123546789012",
        "name": "Email-test",
        "state": "ENABLED",
        "protocol_type": "EXTERNAL",
        "capability": {
        "supported_schema": [
        "email_smtp"
        ]
        },
        "plugin_info": {
        "plugin_id": "plugin-email-noti-protocol",
        "version": "1.0.2",
        "options": {},
        "secret_id": "secret-123546789012",
        "metadata": {
        "data": {
        "schema": {
        "properties": {
        "email": {
        "pattern": "^[\\W]*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4}[\\W]*,{1}[\\W]*)*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4})[\\W]*$",
        "examples": [
        "user1@test.com, user2@test.com"
        ],
        "minLength": 10.0,
        "description": "Email address to receive notifications",
        "type": "string",
        "title": "Email Address"
        }
        },
        "required": [
        "email"
        ],
        "type": "object"
        }
        },
        "data_type": "PLAIN_TEXT"
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "type": "test"
        },
        "domain_id": "domain-123546789012",
        "created_at": "2022-01-01T07:55:57.043Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific Protocol. If a Protocol is disabled, the Notification will not be dispatched, even if it is created.
        request_example: >-
        {
        "protocol_id": "protocol-123456789012"
        }
        response_example: >-
        {
        "protocol_id": "protocol-123546789012",
        "name": "Email-test",
        "state": "DISABLED",
        "protocol_type": "EXTERNAL",
        "capability": {
        "supported_schema": [
        "email_smtp"
        ]
        },
        "plugin_info": {
        "plugin_id": "plugin-email-noti-protocol",
        "version": "1.0.2",
        "options": {},
        "secret_id": "secret-123546789012",
        "metadata": {
        "data": {
        "schema": {
        "properties": {
        "email": {
        "pattern": "^[\\W]*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4}[\\W]*,{1}[\\W]*)*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4})[\\W]*$",
        "examples": [
        "user1@test.com, user2@test.com"
        ],
        "minLength": 10.0,
        "description": "Email address to receive notifications",
        "type": "string",
        "title": "Email Address"
        }
        },
        "required": [
        "email"
        ],
        "type": "object"
        }
        },
        "data_type": "PLAIN_TEXT"
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "type": "test"
        },
        "domain_id": "domain-123546789012",
        "created_at": "2022-01-01T07:55:57.043Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Protocol. If there exists a channel using the Protocol, it cannot be deleted.
        request_example: >-
        {
        "protocol_id": "protocol-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Protocol. Prints detailed information about the Protocol.
        request_example: >-
        {
        "protocol_id": "protocol-123456789012"
        }
        response_example: >-
        {
        "protocol_id": "protocol-123546789012",
        "name": "Email-test",
        "state": "DISABLED",
        "protocol_type": "EXTERNAL",
        "capability": {
        "supported_schema": [
        "email_smtp"
        ]
        },
        "plugin_info": {
        "plugin_id": "plugin-email-noti-protocol",
        "version": "1.0.2",
        "options": {},
        "secret_id": "secret-123546789012",
        "metadata": {
        "data": {
        "schema": {
        "properties": {
        "email": {
        "pattern": "^[\\W]*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4}[\\W]*,{1}[\\W]*)*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4})[\\W]*$",
        "examples": [
        "user1@test.com, user2@test.com"
        ],
        "minLength": 10.0,
        "description": "Email address to receive notifications",
        "type": "string",
        "title": "Email Address"
        }
        },
        "required": [
        "email"
        ],
        "type": "object"
        }
        },
        "data_type": "PLAIN_TEXT"
        },
        "upgrade_mode": "AUTO"
        },
        "tags": {
        "type": "test"
        },
        "domain_id": "domain-123546789012",
        "created_at": "2022-01-01T07:55:57.043Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of Protocols. You can use a query to get a filtered list of Protocols.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results":[
        {
        "protocol_id":"protocol-123456789012",
        "name":"Email",
        "state":"ENABLED",
        "protocol_type":"EXTERNAL",
        "capability":{
        "supported_schema":[
        "email_smtp"
        ]
        },
        "plugin_info":{
        "plugin_id":"plugin-email-noti-protocol",
        "version":"1.0.1",
        "options":{

        },
        "secret_id":"secret-123456789012",
        "metadata":{
        "data_type":"PLAIN_TEXT",
        "data":{
        "schema":{
        "properties":{
        "email":{
        "pattern":"^[\\W]*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4}[\\W]*,{1}[\\W]*)*([\\w+\\-.%]+@[\\w\\-.]+\\.[A-Za-z]{2,4})[\\W]*$",
        "examples":[
        "user1@test.com, user2@test.com"
        ],
        "minLength":10.0,
        "description":"Email address to receive notifications",
        "type":"string",
        "title":"Email Address"
        }
        },
        "required":[
        "email"
        ],
        "type":"object"
        }
        }
        },
        "upgrade_mode":"AUTO"
        },
        "tags":{

        },
        "domain_id":"domain-123456789012",
        "created_at":"2022-01-01T07:55:57.043Z"
        }
        ],
        "total_count":1
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ProtocolServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.CreateProtocolRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.UpdateProtocolRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.SerializeToString,
            ),
            'update_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_plugin,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.UpdateProtocolPluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.GetProtocolRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.notification.v1.Protocol', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Protocol(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/create',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.CreateProtocolRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/update',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.UpdateProtocolRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/update_plugin',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.UpdateProtocolPluginRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/enable',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/disable',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/delete',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/get',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.GetProtocolRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/list',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolQuery.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Protocol/stat',
            spaceone_dot_api_dot_notification_dot_v1_dot_protocol__pb2.ProtocolStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import savings_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2


class SavingsStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get_pl_inventory = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/get_pl_inventory',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlInventoryRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryInfo.FromString,
                )
        self.list_pl_inventory = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/list_pl_inventory',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventorysInfo.FromString,
                )
        self.stat_pl_inventory = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/stat_pl_inventory',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.get_pl_savings_detail = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/get_pl_savings_detail',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSavingsDetailRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailInfo.FromString,
                )
        self.list_pl_savings_detail = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/list_pl_savings_detail',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailsInfo.FromString,
                )
        self.stat_pl_savings_detail = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/stat_pl_savings_detail',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.get_pl_summary = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/get_pl_summary',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSummaryRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryInfo.FromString,
                )
        self.list_pl_summary = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/list_pl_summary',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummariesInfo.FromString,
                )
        self.stat_pl_summary = channel.unary_unary(
                '/spaceone.api.inventory.v1.Savings/stat_pl_summary',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class SavingsServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get_pl_inventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_pl_inventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat_pl_inventory(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_pl_savings_detail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_pl_savings_detail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat_pl_savings_detail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_pl_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_pl_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat_pl_summary(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SavingsServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get_pl_inventory': grpc.unary_unary_rpc_method_handler(
                    servicer.get_pl_inventory,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlInventoryRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryInfo.SerializeToString,
            ),
            'list_pl_inventory': grpc.unary_unary_rpc_method_handler(
                    servicer.list_pl_inventory,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventorysInfo.SerializeToString,
            ),
            'stat_pl_inventory': grpc.unary_unary_rpc_method_handler(
                    servicer.stat_pl_inventory,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'get_pl_savings_detail': grpc.unary_unary_rpc_method_handler(
                    servicer.get_pl_savings_detail,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSavingsDetailRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailInfo.SerializeToString,
            ),
            'list_pl_savings_detail': grpc.unary_unary_rpc_method_handler(
                    servicer.list_pl_savings_detail,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailsInfo.SerializeToString,
            ),
            'stat_pl_savings_detail': grpc.unary_unary_rpc_method_handler(
                    servicer.stat_pl_savings_detail,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'get_pl_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.get_pl_summary,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSummaryRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryInfo.SerializeToString,
            ),
            'list_pl_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.list_pl_summary,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummariesInfo.SerializeToString,
            ),
            'stat_pl_summary': grpc.unary_unary_rpc_method_handler(
                    servicer.stat_pl_summary,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.Savings', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Savings(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get_pl_inventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/get_pl_inventory',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlInventoryRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_pl_inventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/list_pl_inventory',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventorysInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat_pl_inventory(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/stat_pl_inventory',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlInventoryStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_pl_savings_detail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/get_pl_savings_detail',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSavingsDetailRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_pl_savings_detail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/list_pl_savings_detail',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat_pl_savings_detail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/stat_pl_savings_detail',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSavingsDetailStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_pl_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/get_pl_summary',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.GetPlSummaryRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_pl_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/list_pl_summary',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummariesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat_pl_summary(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Savings/stat_pl_summary',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__pb2.PlSummaryStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
